@@ -1,38 +1,35 @@
-"""
-    sphinxcontrib.htmlhelp
-    ~~~~~~~~~~~~~~~~~~~~~~
+"""Build HTML help support files."""
 
-    Build HTML help support files.
-
-    :copyright: Copyright 2007-2019 by the Sphinx team, see README.
-    :license: BSD, see LICENSE for details.
-"""
+from __future__ import annotations
 
 import html
 import os
-import warnings
 from os import path
-from typing import Any, Dict, IO, List, Tuple
+from typing import Any
 
 from docutils import nodes
 from docutils.nodes import Element, Node, document
 
+import sphinx
 from sphinx import addnodes
 from sphinx.application import Sphinx
 from sphinx.builders.html import StandaloneHTMLBuilder
 from sphinx.config import Config
-from sphinx.deprecation import RemovedInSphinx40Warning
 from sphinx.environment.adapters.indexentries import IndexEntries
 from sphinx.locale import get_translation
 from sphinx.util import logging
-from sphinx.util import progress_message
 from sphinx.util.fileutil import copy_asset_file
 from sphinx.util.nodes import NodeMatcher
 from sphinx.util.osutil import make_filename_from_project, relpath
 from sphinx.util.template import SphinxRenderer
 
-from sphinxcontrib.htmlhelp.version import __version__
+if sphinx.version_info[:2] >= (6, 1):
+    from sphinx.util.display import progress_message
+else:
+    from sphinx.util import progress_message  # type: ignore[attr-defined,no-redef]
 
+__version__ = '2.0.6'
+__version_info__ = (2, 0, 6)
 
 logger = logging.getLogger(__name__)
 __ = get_translation(__name__, 'console')
@@ -67,7 +64,7 @@ chm_locales = {
     'no_NB': (0x414, 'cp1252'),
     'pl':    (0x415, 'cp1250'),
     'pt_BR': (0x416, 'cp1252'),
-    'ru':    (0x419, 'cp1251'),
+    'ru':    (0x419, 'windows-1251'),  # emit as <meta chaset='...'>
     'sk':    (0x41b, 'cp1250'),
     'sl':    (0x424, 'cp1250'),
     'sv':    (0x41d, 'cp1252'),
@@ -94,7 +91,7 @@ def chm_htmlescape(s: str, quote: bool = True) -> str:
 class ToCTreeVisitor(nodes.NodeVisitor):
     def __init__(self, document: document) -> None:
         super().__init__(document)
-        self.body = []  # type: List[str]
+        self.body: list[str] = []
         self.depth = 0
 
     def append(self, text: str) -> None:
@@ -169,14 +166,11 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
         if locale is not None:
             self.lcid, self.encoding = locale
 
-    def open_file(self, outdir: str, basename: str, mode: str = 'w') -> IO:
-        # open a file with the correct encoding for the selected language
-        warnings.warn('HTMLHelpBuilder.open_file() is deprecated.',
-                      RemovedInSphinx40Warning)
-        return open(path.join(outdir, basename), mode, encoding=self.encoding,
-                    errors='xmlcharrefreplace')
+    def prepare_writing(self, docnames: set[str]) -> None:
+        super().prepare_writing(docnames)
+        self.globalcontext['html5_doctype'] = False
 
-    def update_page_context(self, pagename: str, templatename: str, ctx: Dict, event_arg: str) -> None:  # NOQA
+    def update_page_context(self, pagename: str, templatename: str, ctx: dict, event_arg: str) -> None:  # NOQA
         ctx['encoding'] = self.encoding
 
     def handle_finish(self) -> None:
@@ -193,7 +187,7 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
 
         super().write_doc(docname, doctree)
 
-    def render(self, name: str, context: Dict) -> str:
+    def render(self, name: str, context: dict) -> str:
         template = SphinxRenderer(template_dir)
         return template.render(name, context)
 
@@ -216,7 +210,7 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
     def build_project_file(self) -> None:
         """Create a project file (.hhp) on outdir."""
         # scan project files
-        project_files = []  # type: List[str]
+        project_files: list[str] = []
         for root, dirs, files in os.walk(self.outdir):
             dirs.sort()
             files.sort()
@@ -261,14 +255,14 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
             }
             f.write(self.render('project.hhc', context))
 
-    def build_hhx(self, outdir: str, outname: str) -> None:
+    def build_hhx(self, outdir: str | os.PathLike[str], outname: str) -> None:
         logger.info(__('writing index file...'))
         index = IndexEntries(self.env).create_index(self)
         filename = path.join(outdir, outname + '.hhk')
         with open(filename, 'w', encoding=self.encoding, errors='xmlcharrefreplace') as f:
             f.write('<UL>\n')
 
-            def write_index(title: str, refs: List[Tuple[str, str]], subitems: List[Tuple[str, List[Tuple[str, str]]]]) -> None:  # NOQA
+            def write_index(title: str, refs: list[tuple[str, str]], subitems: list[tuple[str, list[tuple[str, str]]]]) -> None:  # NOQA
                 def write_param(name: str, value: str) -> None:
                     item = '    <param name="%s" value="%s">\n' % (name, value)
                     f.write(item)
@@ -292,7 +286,7 @@ class HTMLHelpBuilder(StandaloneHTMLBuilder):
                     f.write('</UL>')
             for (key, group) in index:
                 for title, (refs, subitems, key_) in group:
-                    write_index(title, refs, subitems)
+                    write_index(title, refs, subitems)  # type: ignore[arg-type]
             f.write('</UL>\n')
 
 
@@ -301,12 +295,13 @@ def default_htmlhelp_basename(config: Config) -> str:
     return make_filename_from_project(config.project) + 'doc'
 
 
-def setup(app: Sphinx) -> Dict[str, Any]:
+def setup(app: Sphinx) -> dict[str, Any]:
+    app.require_sphinx('5.0')
     app.setup_extension('sphinx.builders.html')
     app.add_builder(HTMLHelpBuilder)
     app.add_message_catalog(__name__, path.join(package_dir, 'locales'))
 
-    app.add_config_value('htmlhelp_basename', default_htmlhelp_basename, None)
+    app.add_config_value('htmlhelp_basename', default_htmlhelp_basename, '')
     app.add_config_value('htmlhelp_file_suffix', None, 'html', [str])
     app.add_config_value('htmlhelp_link_suffix', None, 'html', [str])
 
